@@ -1,8 +1,4 @@
-try:
-    from django.forms import Textarea
-except ImportError:
-    """incase we're installing and django isn't installed"""
-    Textarea = object
+from django.forms import Textarea
 
 class FullScreenTextarea(Textarea):
 
